hekrapi-python
======================
The module provides interfacing with Hekr-enabled devices and accounts, exposing them as interactable objects.

Documentation and support is barebones, but it is expected to improve as more devices are researched into.
